menu
dart_srp package
documentation
custom_x_routine.dart
CustomXRoutine class
CustomXRoutine class
dark_mode
light_mode
CustomXRoutine
class
Inheritance
Object
XRoutine
CustomXRoutine
Constructors
CustomXRoutine
(
BigInt
N
)
Properties
hashCode
→
int
The hash code for this object.
no setter
inherited
N
↔
BigInt
getter/setter pair
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
computeX
(
Hash
digest
,
List
<
int
>
salt
,
List
<
int
>
username
,
List
<
int
>
password
)
→
BigInt
override
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString
(
)
→
String
A string representation of this object.
inherited
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
dart_srp package
documentation
custom_x_routine
CustomXRoutine class
custom_x_routine library