SRP6CryptoParams class

Constructors

SRP6CryptoParams(BigInt N, BigInt g, String H)

Properties

g BigInt
getter/setter pair
H String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
N BigInt
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMessageDigestInstance() → Hash
now it is hard coded SHA-256
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

gCommon BigInt
final
n1024 BigInt
final
n1536 BigInt
final
n2048 BigInt
final
n256 BigInt
final
n512 BigInt
final
n768 BigInt
final

Static Methods

getInstance({int bitsize = 512, String H = "SHA-1"}) SRP6CryptoParams
isSupportedHashAlgorithm(String H) bool
for now yes is supported // TODO check that hash is supported.